# API Reference: Exceptions and Errors

Complete reference for all exception types in bfabricPy.

```{eval-rst}
.. autoclass:: bfabric.errors.BfabricRequestError
    :members:
    :show-inheritance:
```

```{eval-rst}
.. autoclass:: bfabric.errors.BfabricConfigError
    :members:
    :show-inheritance:
```

```{eval-rst}
.. autoclass:: bfabric.errors.BfabricInstanceNotConfiguredError
    :members:
    :show-inheritance:
```

## See Also

- [Error Handling](../../user_guides/error_handling.md) - Complete error handling guide
- [Troubleshooting](../../getting_started/troubleshooting.md) - Solutions to common issues
